import type { BrowserWindow } from 'electron'
import { app, ipcMain } from 'electron'
import type ElectronStore from 'electron-store'
import type { SettingStore } from '/#/store'

export async function useHandler(win: BrowserWindow, store: ElectronStore<SettingStore>) {
    // ==================== ipc handle ===================
    // 关闭程序
    ipcMain.handle('close', () => {
        win.close()
        app.quit()
    })

    // 重新加载
    ipcMain.handle('reload', () => {
        win.reload()
    })

    // 打开 F12
    ipcMain.handle('debug', () => {
        win.webContents.toggleDevTools()
    })

    // 最大化
    ipcMain.handle('max', () => {
        if (win.isMaximized()) {
            win.restore()
        } else {
            win.maximize()
        }
    })

    // 最小化
    ipcMain.handle('min', () => {
        win.minimize()
    })

    // 置顶
    ipcMain.handle('top', (_, value: boolean) => {
        win.setAlwaysOnTop(value)
    })

    // 设置窗口是否总在最前
    if (store.get('system.alwaysOnTop')) {
        win.setAlwaysOnTop(true)
    }
}
